
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.26.0',
    'branch_nick': 'master',
    'revision_id': '52ce8d4b2dcb378947476941208fe4e1e4831ed0',
    'revno': 10776
}
